#include "SevSeg.h"

// ROTATE ENCODER //
int rotateLeftPin = 3;
int rotateRightPin = 2;
int rotateLeftPinstateCurrent = LOW;
int rotateLeftPinStateLast = rotateLeftPinstateCurrent;

// Value rotate encoder
int counter = 1;
int minCounter = 1;
int maxCounter = 4;


// BUTTON ROTATE ENCODER //
int buttonPin = 4;
bool buttonIsPressed = false;

// RELAY //
int relayPin = 13;

// Delay values relay in ML
int delayCounter1 = 8; // 10 ml
int delayCounter2 = 30; // 30 ml
int delayCounter3 = 35; // 35 ml
int delayCounter4 = 40; // 40 ml


// DIGIT BLOCK //
SevSeg sevseg;
byte hardwareConfig = COMMON_CATHODE;
byte numDigits = 1;
byte digitPins[] = {};
byte segmentPins[] = {5, 6, 7, 9, 8, 10, 11, 12};
bool resistorsOnSegments = true;


void setup() {
  Serial.begin (9600);

  // Rotate encoder
  pinMode (rotateLeftPin, INPUT);
  pinMode (rotateRightPin, INPUT);

  // Button
  pinMode (buttonPin, INPUT_PULLUP);

  // Relay
  pinMode (relayPin, OUTPUT);

  // Digit block
  sevseg.begin(hardwareConfig, numDigits, digitPins, segmentPins, resistorsOnSegments);
  sevseg.setBrightness(90);
  showDisplay(counter);
}

void loop() {
  delay(10);

  // DRUKKNOP
  if (digitalRead(buttonPin) == LOW && !buttonIsPressed) {
    callRelay();
  }
  buttonIsPressed = digitalRead(buttonPin) == LOW ? true : false;


  // ROTATIE RICHTING
  if (!buttonIsPressed) {
    checkRotary();
  }

}

void checkRotary() {
  rotateLeftPinstateCurrent = digitalRead(rotateLeftPin);

  // Als er minimaal 1 tik gedraaid is
  if ((rotateLeftPinStateLast == LOW) && (rotateLeftPinstateCurrent == HIGH)) {


    if (digitalRead(rotateRightPin) == HIGH) {
      if (counter != minCounter) {
        counter --;
      }
    } else {
      if (counter != maxCounter) {
        counter ++;
      }
    }
    Serial.println(counter);
    showDisplay(counter);
  }

  rotateLeftPinStateLast = rotateLeftPinstateCurrent;
}

void showDisplay(int counterValue) {
  sevseg.setNumber(counterValue);
  sevseg.refreshDisplay();
}

void callRelay() {
  switch (counter) {
    case 1:
      TurnRelayOn(mlToSeconds(delayCounter1));
      break;
    case 2:
      TurnRelayOn(mlToSeconds(delayCounter2));
      break;
    case 3:
      TurnRelayOn(mlToSeconds(delayCounter3));
      break;
    case 4:
      TurnRelayOn(mlToSeconds(delayCounter4));
      break;
  }
}

int mlToSeconds(int ml) {
  int seconds = 53 * ml;
  Serial.println(seconds);
  return seconds;
}

void TurnRelayOn(int delayValue) {
  Serial.println(delayValue);

  digitalWrite(relayPin, HIGH);
  delay(delayValue);
  digitalWrite(relayPin, LOW);
}
